import * as React from 'react';

import { Core, StoreEvent, StoreKeeper, StoreKeeperImpl, StoreKeeperListener } from 'b-engine-gameengine';
import { GameStateChangeEventListener } from './GameStateChangeEventListener';

export interface LayoutPickerState {
    gameState: string;
}

export interface LayoutPickerProps {
    layouts: {
        [key: string]: any;
    };
}

export class LayoutPicker extends React.Component<LayoutPickerProps, LayoutPickerState> implements StoreKeeperImpl {
    private _core: Core = Core.getInstance();
    private _storeKeeper: StoreKeeper = StoreKeeper.getInstance();

    private _gameStateChangeEventListener: GameStateChangeEventListener;
    private _storeKeeperEventListener: StoreKeeperListener;

    public constructor(props: LayoutPickerProps) {
        super(props);

        this.state = {
            gameState: 'none',
        };

        this._gameStateChangeEventListener = new GameStateChangeEventListener(this);
        this._storeKeeperEventListener = new StoreKeeperListener(this);

        this.switchLayout = this.switchLayout.bind(this);
    }

    public componentWillMount() {
        this._core.gameStateHandler.eventHandler.add(this._gameStateChangeEventListener);
        this._storeKeeper.eventHandler.add(this._storeKeeperEventListener);
    }

    public componentWillUnmount() {
        this._core.gameStateHandler.eventHandler.remove(this._gameStateChangeEventListener);
        this._storeKeeper.eventHandler.remove(this._storeKeeperEventListener);
    }

    public switchLayout(state: string) {
        this.setState({
            gameState: this.props.layouts[state],
        });
    }

    public render() {
        return <div className="layout-container">{this.state.gameState}</div>;
    }

    public storeItemAdd(e: StoreEvent): void {
        console.log('added', e);
    }

    public storeItemDelete(e: StoreEvent): void {
        console.log('deleted', e);
    }

    public storeItemPut(e: StoreEvent): void {
        console.log('putted', e);
    }
}
